==> visual-third-party-2.9-sources.jar: com/tenqube/visual_third/db/dao/ContentsDao.java <==
package com.tenqube.visual_third.db.dao;

import android.content.ContentValues;
import android.database.Cursor;
import android.database.sqlite.SQLiteException;

import com.tenqube.visual_third.db.Db;
import com.tenqube.visual_third.db.QueryGenerator;
import com.tenqube.visual_third.db.ReaderContract;
import com.tenqube.visual_third.entity.Contents;
import com.tenqube.visual_third.model.api.SyncCategoryResponse;

import java.util.ArrayList;

public class ContentsDao {

    private final Db db;

    public ContentsDao(Db db) {
        this.db = db;
    }

    public ArrayList<Contents> loadContents(int lCode) {

        String query = QueryGenerator.contents(lCode);
        ArrayList<Contents> results = new ArrayList<>();
        Cursor c = null;

        try {
            c = db.runQuery(query);
            if(c != null) {
                if(c.moveToFirst()) {
                    while (!c.isAfterLast()) {
                        results.add((ReaderContract.ContentsTable.populateModel(c)));
                        c.moveToNext();
                    }
                }
            }
        } catch (SQLiteException e) {
            e.printStackTrace();
        } finally {
            if(c != null) {
                c.close();
            }
        }

        return results;
    }


    public void mergeCategory(SyncCategoryResponse.Category category) {

        try {
            if(category.isDeleted()) {
                db.delete(ReaderContract.CategoryTable.TABLE_NAME, ReaderContract.CategoryTable._ID + "=?" , new String[]{category.getId() + ""});
            } else {
                ContentValues values = new ContentValues();
                values.put(ReaderContract.CategoryTable._ID, category.getId());
                values.put(ReaderContract.CategoryTable.COLUMN_CODE, category.getCategoryCode());
                values.put(ReaderContract.CategoryTable.COLUMN_LARGE, category.getLargeCategory());
                values.put(ReaderContract.CategoryTable.COLUMN_MEDIUM, category.getMediumCategory());
                values.put(ReaderContract.CategoryTable.COLUMN_SMALL, category.getSmallCategory());
                db.insertOnReplace(ReaderContract.CategoryTable.TABLE_NAME, values);
            }
        } catch (Exception e) {
            e.printStackTrace();
        }

    }
}

==> visual-third-party-3.0-sources.jar: com/tenqube/visual_third/db/dao/ContentsDao.java <==
package com.tenqube.visual_third.db.dao;

import android.content.ContentValues;
import android.database.Cursor;
import android.database.sqlite.SQLiteException;

import com.tenqube.visual_third.db.Db;
import com.tenqube.visual_third.db.QueryGenerator;
import com.tenqube.visual_third.db.ReaderContract;
import com.tenqube.visual_third.entity.Contents;
import com.tenqube.visual_third.model.api.SyncCategoryResponse;

import java.util.ArrayList;

public class ContentsDao {

    private final Db db;

    public ContentsDao(Db db) {
        this.db = db;
    }

    public ArrayList<Contents> loadContents(int lCode) {

//        String query = QueryGenerator.contents(lCode);
//        ArrayList<Contents> results = new ArrayList<>();
//        Cursor c = null;
//
//        try {
//            c = db.runQuery(query);
//            if(c != null) {
//                if(c.moveToFirst()) {
//                    while (!c.isAfterLast()) {
//                        results.add((ReaderContract.ContentsTable.populateModel(c)));
//                        c.moveToNext();
//                    }
//                }
//            }
//        } catch (SQLiteException e) {
//            e.printStackTrace();
//        } finally {
//            if(c != null) {
//                c.close();
//            }
//        }

        return null;
    }


    public void mergeCategory(SyncCategoryResponse.Category category) {

        try {
            if(category.isDeleted()) {
                db.delete(ReaderContract.CategoryTable.TABLE_NAME, ReaderContract.CategoryTable._ID + "=?" , new String[]{category.getId() + ""});
            } else {
                ContentValues values = new ContentValues();
                values.put(ReaderContract.CategoryTable._ID, category.getId());
                values.put(ReaderContract.CategoryTable.COLUMN_CODE, category.getCategoryCode());
                values.put(ReaderContract.CategoryTable.COLUMN_LARGE, category.getLargeCategory());
                values.put(ReaderContract.CategoryTable.COLUMN_MEDIUM, category.getMediumCategory());
                values.put(ReaderContract.CategoryTable.COLUMN_SMALL, category.getSmallCategory());
                db.insertOnReplace(ReaderContract.CategoryTable.TABLE_NAME, values);
            }
        } catch (Exception e) {
            e.printStackTrace();
        }

    }
}
